pub fn selinux_fs(
current_task: &CurrentTask,
options: FileSystemOptions,
) -> Result<FileSystemHandle, Errno>Expand description
Returns the “selinuxfs” file system, used by the system userspace to administer SELinux.
pub fn selinux_fs(
current_task: &CurrentTask,
options: FileSystemOptions,
) -> Result<FileSystemHandle, Errno>Returns the “selinuxfs” file system, used by the system userspace to administer SELinux.